ConnectionRepository class abstract interface

ConnectionRepository exposes a Stream of Connection state changes.

Annotations

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
observe() → Stream<Connection>
Notifies about connection state changes, such as going online or offline.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited