RefreshView class

A widget that wraps a widget with a RefreshIndicator designed to be used with BLoC pattern.

When swipe to refresh gesture is detected a onRefresh callback is executed. The indicator remains visible until the widget is rebuilt.

Inheritance

Constructors

RefreshView({Key? key, required Widget child, VoidCallback? onRefresh, Color? backgroundColor, Color? color, double displacement = 40.0, ScrollNotificationPredicate notificationPredicate = defaultScrollNotificationPredicate, String? semanticsLabel, String? semanticsValue, double strokeWidth = RefreshProgressIndicator.defaultStrokeWidth, double edgeOffset = 0.0, RefreshIndicatorTriggerMode triggerMode = RefreshIndicatorTriggerMode.onEdge})
const

Properties

backgroundColor → Color?
final
child → Widget
final
color → Color?
final
displacement → double
final
edgeOffset → double
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
notificationPredicate → ScrollNotificationPredicate
final
onRefresh → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
final
semanticsValue → String?
final
strokeWidth → double
final
triggerMode → RefreshIndicatorTriggerMode
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _RefreshViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited